@@ -25,6 +25,7 @@ from .concatenate import concatenate
 from .copyto import copyto
 from .count_nonzero import count_nonzero
 from .cumsum import cumsum
+from .det import det
 from .diag import diag
 from .diff import diff
 from .diagonal import diagonal
@@ -72,6 +73,7 @@ from .repeat import repeat
 from .reshape import reshape
 from .result_type import result_type
 from .rint import rint
+from .roots import roots
 from .save import save
 from .savetxt import savetxt
 from .savez import savez
