@@ -49,9 +49,7 @@ def ediff1d(
         arys_.insert(0, numpoly.aspolynomial(to_begin).ravel())
     arys = tuple(numpoly.aspolynomial(ary) for ary in arys_)
     if len(arys) > 1:
-        arys = numpoly.align_dtype(*arys)
         arys = numpoly.align_exponents(*arys)
-        arys = numpoly.align_indeterminants(*arys)
 
     out = numpoly.ndpoly(
         exponents=arys[0].exponents,
