@@ -1,27 +1,36 @@
 """Return the truth value of (x1 > x2) element-wise."""
+from __future__ import annotations
+from typing import Any, Optional
+
 import numpy
 import numpoly
 
+from ..baseclass import PolyLike
 from ..dispatch import implements
 
 
 @implements(numpy.greater)
-def greater(x1, x2, out=None, **kwargs):
+def greater(
+        x1: PolyLike,
+        x2: PolyLike,
+        out: Optional[numpy.ndarray] = None,
+        **kwargs: Any,
+) -> numpy.ndarray:
     """
     Return the truth value of (x1 > x2) element-wise.
 
     Args:
-        x1, x2 (numpoly.ndpoly):
+        x1, x2:
             Input arrays. If ``x1.shape != x2.shape``, they must be
             broadcastable to a common shape (which becomes the shape of the
             output).
-        out (Optional[numpy.ndarray]):
+        out:
             A location into which the result is stored. If provided, it must
             have a shape that the inputs broadcast to. If not provided or
             `None`, a freshly-allocated array is returned. A tuple (possible
             only as a keyword argument) must have length equal to the number of
             outputs.
-        where (Optional[numpy.ndarray]):
+        where:
             This condition is broadcast over the input. At locations where the
             condition is True, the `out` array will be set to the ufunc result.
             Elsewhere, the `out` array will retain its original value. Note
@@ -32,10 +41,9 @@ def greater(x1, x2, out=None, **kwargs):
             Keyword args passed to numpy.ufunc.
 
     Returns:
-        out (numpy.ndarray, scalar):
-            Output array, element-wise comparison of `x1` and `x2`. Typically
-            of type bool, unless ``dtype=object`` is passed. This is a scalar
-            if both `x1` and `x2` are scalars.
+        Output array, element-wise comparison of `x1` and `x2`. Typically of
+        type bool, unless ``dtype=object`` is passed. This is a scalar if both
+        `x1` and `x2` are scalars.
 
     Examples:
         >>> q0, q1 = numpoly.variable(2)
@@ -61,7 +69,7 @@ def greater(x1, x2, out=None, **kwargs):
     if out is None:
         out = numpy.greater(coefficients1[0], coefficients2[0], **kwargs)
     if not out.shape:
-        return bool(greater(x1.ravel(), x2.ravel(), out=out.ravel()).item())
+        return greater(x1.ravel(), x2.ravel(), out=out.ravel()).item()
 
     options = numpoly.get_options()
     for idx in numpoly.glexsort(x1.exponents.T, graded=options["sort_graded"],
