@@ -1,12 +1,21 @@
 """Return true where two arrays are element-wise equal within a tolerance."""
+from __future__ import annotations
+
 import numpy
 import numpoly
 
-from ..dispatch import implements, simple_dispatch
+from ..baseclass import PolyLike
+from ..dispatch import implements
 
 
 @implements(numpy.isclose)
-def isclose(a, b, rtol=1e-5, atol=1e-8, equal_nan=False):
+def isclose(
+        a: PolyLike,
+        b: PolyLike,
+        rtol: float = 1e-5,
+        atol: float = 1e-8,
+        equal_nan: bool = False,
+) -> numpy.ndarray:
     """
     Return true where two arrays are element-wise equal within a tolerance.
 
@@ -19,21 +28,20 @@ def isclose(a, b, rtol=1e-5, atol=1e-8, equal_nan=False):
                 that are much smaller than one (see Notes).
 
     Args:
-        a, b (numpoly.ndpoly):
+        a, b:
             Input arrays to compare.
-        rtol (float):
+        rtol:
             The relative tolerance parameter (see Notes).
-        atol (float):
+        atol:
             The absolute tolerance parameter (see Notes).
-        equal_nan (bool):
+        equal_nan:
             Whether to compare NaN's as equal.  If True, NaN's in `a` will be
             considered equal to NaN's in `b` in the output array.
 
     Returns:
-        (numpy.ndarray):
-            Returns a boolean array of where `a` and `b` are equal within the
-            given tolerance. If both `a` and `b` are scalars, returns a single
-            boolean value.
+        Returns a boolean array of where `a` and `b` are equal within the
+        given tolerance. If both `a` and `b` are scalars, returns a single
+        boolean value.
 
     Notes:
         For finite values, isclose uses the following equation to test whether
@@ -52,15 +60,15 @@ def isclose(a, b, rtol=1e-5, atol=1e-8, equal_nan=False):
         value for `atol` will result in `False` if either `a` or `b` is zero.
 
     Examples:
-        >>> x, y = numpoly.symbols("x y")
-        >>> numpoly.isclose([1e10*x, 1e-7], [1.00001e10*x, 1e-8])
+        >>> q0, q1 = numpoly.variable(2)
+        >>> numpoly.isclose([1e10*q0, 1e-7], [1.00001e10*q0, 1e-8])
         array([ True, False])
-        >>> numpoly.isclose([1e10*x, 1e-8], [1.00001e10*x, 1e-9])
+        >>> numpoly.isclose([1e10*q0, 1e-8], [1.00001e10*q0, 1e-9])
         array([ True,  True])
-        >>> numpoly.isclose([1e10*x, 1e-8], [1.00001e10*y, 1e-9])
+        >>> numpoly.isclose([1e10*q0, 1e-8], [1.00001e10*q1, 1e-9])
         array([False,  True])
-        >>> numpoly.isclose([x, numpy.nan],
-        ...                 [x, numpy.nan], equal_nan=True)
+        >>> numpoly.isclose([q0, numpy.nan],
+        ...                 [q0, numpy.nan], equal_nan=True)
         array([ True,  True])
 
     """
@@ -68,5 +76,5 @@ def isclose(a, b, rtol=1e-5, atol=1e-8, equal_nan=False):
     out = numpy.ones(a.shape, dtype=bool)
     for key in a.keys:
         out &= numpy.isclose(
-            a[key], b[key], atol=atol, rtol=rtol, equal_nan=equal_nan)
+            a.values[key], b.values[key], atol=atol, rtol=rtol, equal_nan=equal_nan)
     return out
