@@ -1,19 +1,24 @@
 """Convert numpoly.ndpoly to sympy polynomial."""
+from __future__ import annotations
+from typing import Any
+
 import numpy
+import numpoly
+
+from .baseclass import PolyLike
 
 
-def to_sympy(poly):
+def to_sympy(poly: PolyLike) -> Any:
     """
     Convert numpoly object to sympy object, or array of sympy objects.
 
     Args:
-        poly (numpoly.ndpoly):
+        poly:
             Polynomial object to convert to sympy.
 
     Returns:
-        (numpy.ndarray, sympy.core.expr.Expr):
-            If scalar, a sympy expression object, or if array, numpy.array with
-            expression object values.
+        If scalar, a sympy expression object, or if array, numpy.array with
+        expression object values.
 
     Examples:
         >>> q0, q1 = numpoly.variable(2)
@@ -26,9 +31,10 @@ def to_sympy(poly):
         <class 'sympy.core.mul.Mul'>
 
     """
+    poly = numpoly.aspolynomial(poly)
     if poly.shape:
         return numpy.array([to_sympy(poly_) for poly_ in poly])
-    from sympy import symbols
+    from sympy import symbols  # type: ignore
     locals_ = dict(zip(poly.names, symbols(poly.names)))
     polynomial = eval(str(poly), locals_, {})  # pylint: disable=eval-used
     return polynomial
